@@ -61,6 +61,7 @@ static sslsock *getsock(int fd) {
 
 static sslsock *addsock(int fd) {
     sslsock *p;
+    
 #ifdef HAVE_GNUTLS
     gnutls_certificate_credentials_t xcred;
 #endif
@@ -87,7 +88,7 @@ static sslsock *addsock(int fd) {
     }
     p->ssl = SSL_new(ctx);
     SSL_set_fd(p->ssl, p->fd = fd);
-#elif HAVE_GNUTLS
+#elif defined(HAVE_GNUTLS)
     gnutls_global_init ();
     gnutls_certificate_allocate_credentials (&xcred);
     gnutls_init (&(p->session), GNUTLS_CLIENT);
@@ -96,21 +97,21 @@ static sslsock *addsock(int fd) {
     p->fd = fd;
     gnutls_transport_set_ptr(p->session,(gnutls_transport_ptr_t)fd);
 #endif
+
     return p;
 }
 
 static void delsock(int fd) {
     int i, nsockcount;
     sslsock *nsocks;
-
-    if (sockcount > 1)
+    
+    if (sockcount > 0)
     {
     nsockcount = 0;
-    nsocks = (sslsock *) malloc(sizeof(sslsock)*(sockcount-1));
 
     for(i = 0; i < sockcount; i++) {
 	if(socks[i].fd != fd) {
-	    nsocks[nsockcount++] = socks[i];
+	    socks[nsockcount++] = socks[i];
 	} 
 #if defined(HAVE_OPENSSL) || defined(HAVE_NSS_COMPAT)
 	else {
@@ -124,18 +125,9 @@ static void delsock(int fd) {
 #endif
     }
 
-    free(socks);
-
-    socks = nsocks;
+    socks = realloc(socks, sizeof(sslsock)*(nsockcount));
     sockcount = nsockcount;
     }
-    else
-    {
-	if (socks)
-	    free(socks);
-	socks = 0;
-	sockcount = 0;
-    }
 }
 
 #endif
@@ -287,16 +279,26 @@ int cw_connect(int sockfd, const struct sockaddr *serv_addr, int addrlen, int ss
      	rc = connect(sockfd, serv_addr, addrlen);
      }
 
-#if defined(HAVE_OPENSSL) || defined(HAVE_NSS_COMPAT)
+#ifdef HAVE_SSL
     if(ssl && !rc) {
 	sslsock *p = addsock(sockfd);
+#if defined(HAVE_OPENSSL) || defined(HAVE_NSS_COMPAT)
 	if(SSL_connect(p->ssl) != 1){
-	    //printf("Can't connect to SSL\n");
+	    //fprintf(stderr, "cw_connect(%d) - cannot connect to SSL\n", sockfd);
 	    return -1;
 	}
+#elif defined(HAVE_GNUTLS)
+	int ret;
+	do {
+	    ret = gnutls_handshake(p->session);
+	} while ((ret == GNUTLS_E_AGAIN) || (ret == GNUTLS_E_INTERRUPTED));
+	if (ret < 0) {
+	      gnutls_perror (ret);
+	      return -1;
+        }
+#endif
     }
 #endif
-
     return rc;
 }
 
@@ -335,9 +337,8 @@ int cw_nb_connect(int sockfd, const struct sockaddr *serv_addr, int addrlen, int
 	else{ /* check if the socket is connected correctly */
 	    int optlen = sizeof(int), optval;
 	    if (getsockopt(sockfd, SOL_SOCKET, SO_ERROR, &optval, &optlen) || optval){
-            	
 	        /* Look for a better solution to print errors */
-	        //fprintf(stderr,"getsockopt error!!");
+	        //fprintf(stderr,"cw_nb_connect(%d): getsockopt error!!\n", sockfd);
 	        return -1;
 	    }
 	}
@@ -350,19 +351,26 @@ int cw_nb_connect(int sockfd, const struct sockaddr *serv_addr, int addrlen, int
 		p = addsock(sockfd);
 	    
 #ifdef HAVE_GNUTLS
-	    do{
-	       ret = gnutls_handshake(p->session);
-	    }while ((ret == GNUTLS_E_AGAIN) || (ret == GNUTLS_E_INTERRUPTED));
-	    if (ret < 0) {
-	      gnutls_deinit(p->session);
+           ret = gnutls_handshake(p->session);
+	    switch (ret) {
+	    case GNUTLS_E_SUCCESS:
+		*state = 0;
+		return 0;
+	    case GNUTLS_E_INTERRUPTED:
+	    case GNUTLS_E_AGAIN:
+		if (gnutls_record_get_direction(p->session)) {
+		    *state = CW_CONNECT_SSL | CW_CONNECT_WANT_READ;
+		} else {
+		    *state = CW_CONNECT_SSL | CW_CONNECT_WANT_WRITE;
+		}
+		return 0;
+	    default:
+/*	      gnutls_deinit(p->session);
+		will be dealt with in delsock()
+*/
 	      gnutls_perror (ret);
 	      return -1;
 	    }
-	    else{
-  	      *state = 1;
-	      return 0;
-	    }
-        }
 #elif defined(HAVE_OPENSSL) || defined(HAVE_NSS_COMPAT)
 	    rc = SSL_connect(p->ssl);
 	    switch(rc){
@@ -383,9 +391,8 @@ int cw_nb_connect(int sockfd, const struct sockaddr *serv_addr, int addrlen, int
 		    return -1;
 		}
 	    }
-	}
 #endif
-	else{ // catch EINPROGRESS error from the connect call 
+	} else { // catch EINPROGRESS error from the connect call 
 	    if (errno == EINPROGRESS){
 		*state = CW_CONNECT_STARTED | CW_CONNECT_WANT_WRITE;
 		return 0;
