@@ -198,6 +198,8 @@ static fte_t
 }
 
 static char *irc_html_to_irc(const char *const string) {
+	return string;
+/*
 	static char *output = NULL;
 	int o = 0;
 	size_t l,i=0;
@@ -278,6 +280,7 @@ static char *irc_html_to_irc(const char *const string) {
 	assert(o <= ((l * 4) + 1));
 	output[o] = '\0';
 	return(output);
+	*/
 }
 
 static const char *mIRCar[] = {
@@ -329,6 +332,8 @@ static const char *irc_mIRC_to_html(const char *const string, size_t *pos) {
 }
 
 static char *irc_irc_to_html(const char *const string) {
+	return string;
+/*
 	static char *output = NULL;
 	int	o = 0;
 	size_t	l, i = 0, s;
@@ -539,7 +544,7 @@ static char *irc_irc_to_html(const char *const string) {
 
 	output[o] = '\0';
 
-	return(output);
+	return(output);*/
 }
 
 static int irc_internal_disconnect(irc_conn_t *c, const int error) {
@@ -738,6 +743,16 @@ static irc_conn_t
 
 static fte_t
 	irc_signon(irc_conn_t *c, const char *const nickname) {
+	
+	char pass[129];
+	*pass=0;
+	
+	firetalk_callback_needpass(c, pass, sizeof(pass));
+
+	if(strlen(pass))
+	if(irc_send_printf(c, "PASS %s", pass) != FE_SUCCESS)
+		return FE_PACKET;
+	 
 #if defined(HAVE_GETPWUID) && defined(HAVE_GETUID)
 	struct passwd	*pw = getpwuid(getuid());
 	char	buf[1024];
@@ -1282,12 +1297,15 @@ static fte_t irc_got_data_parse(irc_conn_t *c, char **args) {
 				irc_addwhois(c, args[3], "%s@%s (<HTML>%s</HTML>)", args[4], args[5], gecos);
 			return(FE_SUCCESS);
 		} else if (numeric == 352) { /* WHO output */
-			char	buf[1024];
+			char	buf[1024], buf2[1024];
 			int	i;
 
 			snprintf(buf, sizeof(buf), "%s %s %s %s", args[7], args[4], args[5], args[6]);
 			for (i = 8; args[i] != NULL; i++)
-				snprintf(buf, sizeof(buf), "%s, %s", buf, args[i]);
+			{
+				snprintf(buf2, sizeof(buf2), ", %s", args[i]);
+				strncat(buf, buf2, sizeof(buf)-strlen(buf)-1);
+			}
 			firetalk_callback_chat_getmessage(c, ":RAW", args[3], 0, buf);
 			return(FE_SUCCESS);
 		}
@@ -1306,13 +1324,16 @@ static fte_t irc_got_data_parse(irc_conn_t *c, char **args) {
 			snprintf(buf+strlen(buf), sizeof(buf)-strlen(buf), " (%s)", args[1]);
 			irc_addwhois(c, args[3], "%s", buf);
 		} else {
-			char	buf[1024];
+			char	buf[1024], buf2[1024];
 			int	i;
 
 			*buf = 0;
 			for (i = 1; args[i+1] != NULL; i++)
-				snprintf(buf, sizeof(buf), "%s<B>%s</B>, ", buf, args[i]);
-			snprintf(buf, sizeof(buf), "%s%s", buf, args[i]);
+			{
+				snprintf(buf2, sizeof(buf2), "<B>%s</B>, ", args[i]);
+				strncat(buf, buf2, sizeof(buf)-strlen(buf)-1);
+			}
+			strncat(buf, args[i], sizeof(buf)-strlen(buf)-1);
 			firetalk_callback_chat_getmessage(c, ":RAW", irc_get_nickname(args[0]), 0, buf);
 		}
 	}
