@@ -38,9 +38,11 @@
 #include <stdlib.h>
 #include <time.h>
 #include <unistd.h>
-#if defined(HAVE_OPENSSL) || defined(HAVE_NSS_COMPAT)
+#if defined(HAVE_OPENSSL)
 #  include <openssl/err.h>
 #  include <openssl/x509.h>
+#elif defined(HAVE_NSS_COMPAT)
+#  include <nss_compat_ossl/nss_compat_ossl.h>
 #elif HAVE_GNUTLS
 #  include <gnutls/gnutls.h>
 #endif
@@ -578,7 +580,7 @@ static int gg_watch_fd_connected(struct gg_session *sess, struct gg_event *e)
 				if (GG_S_D(n->status)) {
 					unsigned char descr_len = *((char*) n + sizeof(struct gg_notify_reply60));
 
-					if (descr_len < length) {
+					if (sizeof(struct gg_notify_reply60) + descr_len < length) {
 						if (!(e->event.notify60[i].descr = malloc(descr_len + 1))) {
 							gg_debug(GG_DEBUG_MISC, "// gg_watch_fd_connected() not enough memory for notify data\n");
 							goto fail;
