@@ -46,6 +46,7 @@ namespace ICQ2000
   class MessageSNAC;
   class MessageACKSNAC;
   class MessageOfflineUserSNAC;
+  class MessageTypingNotificationSNAC;
   class SrvResponseSNAC;
   class UINResponseSNAC;
   class RateInfoChangeSNAC;
@@ -107,6 +108,7 @@ namespace ICQ2000
     std::map<unsigned short, std::string> m_sbl_groupnames; // group_id::group_name
     std::set<unsigned short> m_sbl_tags; // used tag ids
     bool m_sbl_canedit; // local SBL is ready, I can do edits on it
+    unsigned short m_sbl_privacy_id; // privacy buddy ID
     
     ContactRef m_self;
     std::string m_password;
@@ -187,6 +189,7 @@ namespace ICQ2000
     void SignalMessage(MessageSNAC *snac);
     void SignalMessageACK(MessageACKSNAC *snac);
     void SignalMessageOfflineUser(MessageOfflineUserSNAC *snac);
+    void SignalTypingNotification(MessageTypingNotificationSNAC *snac);
     void SignalSrvResponse(SrvResponseSNAC *snac);
     void SignalUINResponse(UINResponseSNAC *snac);
     void SignalUINRequestError();
@@ -356,6 +359,12 @@ namespace ICQ2000
      */
     sigslot::signal1<StatusChangeEvent*> contact_status_change_signal;
 
+    /**
+     *  The signal to connect to for listening for Contact Typing Notification events.
+     * @see UserTypingNotificationEvent
+     */
+    sigslot::signal1<UserTypingNotificationEvent*> contact_typing_signal;
+
     /**
      *  The signal for when registering a new UIN has succeeded or
      *  failed after a call to RegisterUIN().
