@@ -41,6 +41,11 @@
   #include "imotr.h"
 #endif
 
+#ifdef HAVE_LIBXSS
+  #include <X11/extensions/scrnsaver.h>
+#endif
+
+volatile bool centerim::signaled = false;
 
 centerim::centerim()
     : timer_checkmail(0), timer_update(0), timer_resend(0),
@@ -801,11 +806,12 @@ void centerim::handlesignal(int signum) {
 
     switch(signum) {
 	case SIGCHLD:
-	    while((pid = wait3(&status, WNOHANG, 0)) > 0) {
+	    /*while((pid = wait3(&status, WNOHANG, 0)) > 0) {
 		// In case the child was a nowait external action
 		string sname = conf->getdirname() + "centerim-external-tmp." + i2str(pid);
 		unlink(sname.c_str());
-	    }
+	    }*/
+	    signaled = true;
 	    break;
 
 	case SIGUSR1:
@@ -1500,6 +1506,7 @@ void centerim::exectimers() {
     protocolname pname;
     int paway, pna;
     bool fonline = false;
+    bool pusex = false;
 
     time(&timer_current);
 
@@ -1556,7 +1563,7 @@ void centerim::exectimers() {
     * How let's find out how are the auto-away mode is doing.
     *
     */
-	conf->getauto(paway, pna);
+	conf->getauto(paway, pna, pusex);
 	
 	if(fonline && (paway || pna || conf->getscreenna())) {
 		imstatus toset = offline;
@@ -1572,6 +1579,7 @@ void centerim::exectimers() {
 		 * Use auto-away or auto-na?
 		 */
 		if(paway || pna) {
+#ifndef HAVE_LIBXSS
 			if(paway && timer_current-timer_keypress > paway*60)
 				toset = away;
 
@@ -1580,6 +1588,32 @@ void centerim::exectimers() {
 
 			if(timer_current-timer_keypress < MINCK0(paway, pna)*60)
 				toset = available;
+#else
+			time_t idle_time = timer_current - timer_keypress;
+			if (pusex) {
+				Display* dpy = XOpenDisplay(0);
+				if (dpy) {
+					XScreenSaverInfo i;
+					Status s = XScreenSaverQueryInfo(dpy,
+							DefaultRootWindow(dpy),
+							&i);
+					if (s != 0) {
+						// XScreenSaver extension supported
+						idle_time = i.idle / 1000;
+					}
+					XCloseDisplay(dpy);
+				}
+			}
+
+			if(paway && idle_time > paway*60)
+				toset = away;
+
+			if(pna && idle_time > pna*60)
+				toset = notavail;
+
+			if(idle_time < MINCK0(paway, pna)*60)
+				toset = available;
+#endif
 		}
 
 		/*
@@ -1664,6 +1698,15 @@ void centerim::exectimers() {
 		face.log(_("! otherwise we can lose events and configuration"));
 	    }
 	} else {
+	
+	    if (signaled) { /* Check for finished external actions */
+		signaled = false;
+		pid_t child;
+		while ((child = waitpid(-1, NULL, WNOHANG)) > 0) {
+		    string sname = conf->getdirname() + "centerim-external-tmp." + i2str(child);
+		    unlink(sname.c_str());
+		}
+	    }
 	    /*
 	    *
 	    * Re-send the idle IM events.
@@ -1783,3 +1826,15 @@ string lo(string s) {
 
     return s;
 }
+
+string stripspaces(string s) {
+    string::iterator is = s.begin();
+    string result;
+    while (is != s.end()) {
+	if (*is != ' ')
+	    result.push_back(*is);
+	is++;
+    };
+    
+    return result;
+}
