@@ -55,11 +55,6 @@ int main(int argc, char **argv) {
 
     getcwd(savedir, 1024);
 
-    // This will set the default umask to 0x077, see umask(2) for details
-    // This makes sure that all newly created files in ~/.centerim gets the
-    // proper protection (the group and other bits are zeroed).
-    umask (S_IRWXG | S_IRWXO);
-
     try {
         srand((unsigned int) time(NULL));
 
