@@ -14,6 +14,7 @@ struct hookcapab {
 	authreqwithmessages,
 	fetchaway,
 	setaway,
+	setextstatus,
 	changenick,
 	changepassword,
 	changedetails,
@@ -32,6 +33,7 @@ struct hookcapab {
 	channelpasswords,
 	groupchatservices,
 	nochat,
+	acknowledgements,
 	pgp
     };
 };
