@@ -89,6 +89,7 @@ icqhook::icqhook(): abstracthook(icq) {
     cli.contactlist.connect(this, &icqhook::contactlist_cb);
     cli.contact_userinfo_change_signal.connect(this, &icqhook::contact_userinfo_change_signal_cb);
     cli.contact_status_change_signal.connect(this, &icqhook::contact_status_change_signal_cb);
+    cli.contact_typing_signal.connect(this, &icqhook::contact_typing_signal_cb);
     cli.newuin.connect(this, &icqhook::newuin_cb);
     cli.rate.connect(this, &icqhook::rate_cb);
 //    cli.password_changed.connect(this, &icqhook::password_changed_cb);
@@ -1354,8 +1355,15 @@ void icqhook::contact_status_change_signal_cb(StatusChangeEvent *ev) {
 
 	if(ic->isInvisible()) nst = invisible;
 
+        c->setidlefor(ic->getExtPort());
 	logger.putonline(c, c->getstatus(), nst);
 	c->setstatus(nst);
+
+        if (ic->get_signon_time())
+	    c->setonlinesince(ic->get_signon_time());
+
+	if (nst == offline)
+	    c->setlasttyping(0);
     }
 }
 
@@ -1406,7 +1414,16 @@ void icqhook::contact_userinfo_change_signal_cb(UserInfoChangeEvent *ev) {
                 c->setlastip(oldip);
             }
         }
+    }
+}
 
+void icqhook::contact_typing_signal_cb(UserTypingNotificationEvent *ev) {
+    icqcontact *c = clist.get(imcontact(ev->getUIN(), icq));
+    if(c)
+    {
+	time_t when = ev->isTyping() ? (time(NULL) + 300) : 0;  // nobody should type for more than five minutes without a break...
+	c->setlasttyping(when);
+	face.relaxedupdate();
     }
 }
 
