@@ -68,7 +68,7 @@ irchook::~irchook() {
 void irchook::init() {
     int i;
 
-    manualstatus = conf.getstatus(irc);
+    manualstatus = conf->getstatus(irc);
 
     for(i = 0; i < clist.count; i++) {
 	icqcontact *c = (icqcontact *) clist.at(i);
@@ -125,12 +125,12 @@ void irchook::init() {
     firetalk_subcode_register_reply_callback(handle, "PING", &subreply);
     firetalk_subcode_register_reply_callback(handle, "VERSION", &subreply);
 
-    if(conf.getdebug())
+    if(conf->getdebug())
 	firetalk_register_callback(handle, FC_LOG, &fclog);
 }
 
 void irchook::connect() {
-    icqconf::imaccount acc = conf.getourid(irc);
+    icqconf::imaccount acc = conf->getourid(irc);
     log(logConnecting);
 
     firetalk_register_callback(handle, FC_DISCONNECT, 0);
@@ -228,7 +228,7 @@ bool irchook::send(const imevent &ev) {
     if(c) {
 	if(ev.gettype() == imevent::message) {
 	    const immessage *m = static_cast<const immessage *>(&ev);
-	    text = rushtmlconv("kw", m->gettext());
+	    text = rusconv("kw", m->gettext());
 
 	} else if(ev.gettype() == imevent::url) {
 	    const imurl *m = static_cast<const imurl *>(&ev);
@@ -275,7 +275,7 @@ bool irchook::send(const imevent &ev) {
 	else
 	{
 		text = original;
-		original.clear();
+		original.erase();
 	}
 	if(text.substr(0, 1) == "/") {
 	    text.erase(0, 1);
@@ -377,7 +377,7 @@ void irchook::setautostatus(imstatus st) {
 		    case notavail:
 		    case outforlunch:
 		    case occupied:
-			firetalk_set_away(handle, conf.getawaymsg(irc).c_str(), 0);
+			firetalk_set_away(handle, conf->getawaymsg(irc).c_str(), 0);
 			break;
 
 		    default:
@@ -557,7 +557,7 @@ void irchook::processnicks() {
 	c = new icqcontact(imcontact(dnick, irc));
 	c->setdispnick(dnick);
 
-	searchdest->additem(conf.getcolor(cp_clist_irc), c, (string) " " + *in);
+	searchdest->additem(conf->getcolor(cp_clist_irc), c, (string) " " + *in);
 	foundguys.push_back(c);
     }
 
@@ -617,7 +617,10 @@ void irchook::setautochannels(vector<channelInfo> &achannels) {
 	if(iac->joined) {
 	    r = ic == channels.end();
 	    if(!r) r = !ic->joined;
-	    if(r) firetalk_chat_join(irhook.handle, iac->name.c_str());
+	    string passname = iac->name;
+	    if (!iac->passwd.empty())
+	    	passname += " " + iac->passwd;
+	    if(r) firetalk_chat_join(irhook.handle, passname.c_str());
 	}
     }
 
@@ -772,7 +775,10 @@ void irchook::connected(void *conn, void *cli, ...) {
 
     for(ic = irhook.channels.begin(); ic != irhook.channels.end(); ++ic) {
 	if(ic->joined) {
-	    firetalk_chat_join(irhook.handle, ic->name.c_str());
+	    string passname = ic->name;
+	    if (!ic->passwd.empty())
+	    	passname += " " + ic->passwd;
+	    firetalk_chat_join(irhook.handle, passname.c_str());
 	}
     }
 
@@ -819,9 +825,9 @@ void irchook::newnick(void *conn, void *cli, ...) {
 
     if(nick)
     if(strlen(nick)) {
-	icqconf::imaccount acc = conf.getourid(irc);
+	icqconf::imaccount acc = conf->getourid(irc);
 	acc.nickname = nick;
-	conf.setourid(acc);
+	conf->setourid(acc);
 
 	face.log(_("+ [irc] nickname was changed successfully"));
     }
@@ -908,13 +914,13 @@ void irchook::getmessage(void *conn, void *cli, ...) {
 
     if(sender && message)
     if(strlen(sender) && strlen(message)) {
-	if(!irhook.sentpass)
+	/*if(!irhook.sentpass)  // NickServ identify should be handled by firetalk and needpass callback
 	if(up(sender) == "NICKSERV") {
 	    firetalk_im_send_message(irhook.handle, "NickServ",
-		((string) "identify " + conf.getourid(irc).additional["nickpass"]).c_str(), 0);
+		((string) "identify " + conf->getourid(irc).additional["nickpass"]).c_str(), 0);
 
 	    irhook.sentpass = true;
-	}
+	}*/
 
 	em.store(immessage(imcontact(sender, irc),
 	    imevent::incoming, irhook.rushtmlconv("wk", cuthtml(message, chCutBR | chLeaveLinks))));
@@ -1274,12 +1280,24 @@ void irchook::needpass(void *conn, void *cli, ...) {
     va_end(ap);
 
     if(pass) {
-	icqconf::imaccount acc = conf.getourid(irc);
+	icqconf::imaccount acc = conf->getourid(irc);
 
-	if(!acc.password.empty()) {
-	    strncpy(pass, acc.password.c_str(), size-1);
-	    pass[size-1] = 0;
-	    face.log(_("+ [irc] password sent"));
+	if (size == 129)  // signon password
+	{
+		if(!acc.password.empty()) {
+	    	strncpy(pass, acc.password.c_str(), size-1);
+	    	pass[size-1] = 0;
+	    	face.log(_("+ [irc] password sent"));
+		}
+	}
+	else // NickServ password
+	{
+		irhook.sentpass = true;
+		if(!acc.additional["nickpass"].empty()) {
+	    	strncpy(pass, acc.additional["nickpass"].c_str(), size-1);
+	    	pass[size-1] = 0;
+	    	face.log(_("+ [irc] nick password sent"));
+		}
 	}
     }
 }
@@ -1413,7 +1431,7 @@ void irchook::chatuserjoined(void *conn, void *cli, ...) {
     char *email = va_arg(ap, char *);
     va_end(ap);
 
-    if(conf.getourid(irc).nickname != who) {
+    if(conf->getourid(irc).nickname != who) {
 	string uname = who;
 
 	if(email)
@@ -1435,7 +1453,7 @@ void irchook::chatuserleft(void *conn, void *cli, ...) {
     char *reason = va_arg(ap, char *);
     va_end(ap);
 
-    if(conf.getourid(irc).nickname != who) {
+    if(conf->getourid(irc).nickname != who) {
 	string text;
 	string text2;
 	char buf[NOTIFBUF];
@@ -1464,7 +1482,7 @@ void irchook::chatuserkicked(void *conn, void *cli, ...) {
     char *reason = va_arg(ap, char *);
     va_end(ap);
 
-    if(conf.getourid(irc).nickname != who) {
+    if(conf->getourid(irc).nickname != who) {
 	string text;
 	char buf[NOTIFBUF];
 
