@@ -53,7 +53,9 @@ icqconf* icqconf::instance()
 	return self;
 }
 
-icqconf::icqconf() {
+icqconf::icqconf() : showopenedchats(false), quote(false), dropauthreq(false),
+    usingcaptcha(false), screenna(false), askquit(false), bidi(false)
+{
     DEFAULT_TIMESTAMP_FORMAT = "DD.MM.YY hh:mm";
     DEFAULT_LOGTIMESTAMP_FORMAT = "%R ";
     SECONDS_TIMESTAMP_FORMAT = "DD.MM.YY hh:mm:ss";
@@ -275,51 +277,24 @@ void icqconf::checkdir() {
     string dname = getdirname();
     dname.erase(dname.size()-1);
     const char * dirstr = dname.c_str();
-    const mode_t mask = umask (S_IRWXG | S_IRWXO); // All rights for group and other
+    // The proper rights for the ~/.centerim-directory
+    const mode_t proper_rights = S_IRUSR | S_IWUSR | S_IXUSR;
 
     if(access(dirstr, F_OK) == 0) {
          // Directory allready exists check the permissions of the directory.
         struct stat dir_stat;
         if (  stat(dirstr, &dir_stat) == 0 &&
-              (dir_stat.st_mode & mask) != 0 ) {
+              (dir_stat.st_mode & ~proper_rights) != 0 ) {
             DIR *pDir = NULL;
             // group / other have some kind of permissions for this directory
             // as mr Picard would have said: compensate!
-            chmod (dirstr, dir_stat.st_mode & ~mask);
-
-            // TODO: make sure that all subfiles got the right permissions, that is not done now.
-
-            // Make sure that atleast the configuration files are not readable for others
-            // Umask is set in centermain.cc, so all newly created files will be protected
-            // However if the ~/.centerim / ~/.centericq directory was created by an old
-            // version of centerim, then the rights will not be properly set up.
-
-            pDir = opendir(dirstr);
-
-            if (pDir != NULL) {
-                string tempString = string("");
-
-                struct dirent *pDirent = NULL;
-                while ( (pDirent = readdir(pDir)) != NULL ) {
-                    // only pDir->dname standaridized in POSIX?
-                    tempString = dirstr;
-                    tempString.append("/");
-                    tempString.append(pDirent->d_name);
-                    const char * pFilePath = tempString.c_str();
-
-                    if (stat(pFilePath, &dir_stat) == 0 &&
-                      (dir_stat.st_mode & mask) != 0 ) {
-                        chmod (pFilePath, dir_stat.st_mode & ~mask);
-                    }
-                }
-                closedir(pDir);
-            }
+            chmod (dirstr, proper_rights);
         }
     }
     else{
         // create the ~/.centerim directory since
         // ~/.centerim / ~/.centericq does not exist.
-        mkdir(dname.c_str(), S_IRUSR | S_IWUSR | S_IXUSR);
+        mkdir(dname.c_str(), proper_rights);
     }
 }
 
