@@ -48,6 +48,7 @@ icqcontact::icqcontact(const imcontact adesc) {
     finlist = true;
     congratulated = false;
     openedforchat = false;
+    idlefor = 0;
 
     for(ie = imevent::message; ie != imevent::imeventtype_size; ie++)
 	sound[ie] = "";
@@ -125,7 +126,7 @@ void icqcontact::clear() {
     background.clear();
 
     nick = about = dispnick = postponed = lastip = "";
-    lastseen = 0;
+    lastseen = onlinesince = 0;
 }
 
 void icqcontact::save() {
@@ -519,6 +520,13 @@ void icqcontact::setstatus(imstatus fstatus, bool reflect) {
 
 	}
 
+	if (fstatus == offline && status != offline) {
+	    setonlinesince(0);
+	}
+	else if (fstatus != offline && status == offline) {
+	    setonlinesince(time(NULL));
+	}
+
 	setlastseen();
 	status = fstatus;
 	face.relaxedupdate();
@@ -726,6 +734,21 @@ time_t icqcontact::getlastseen() const {
     return lastseen;
 }
 
+void icqcontact::setidlefor(unsigned int idle) {
+    if (idle > 0)
+    {
+	time(&idlefor);
+	idlefor -= (idle * 60);
+    }
+    else
+	idlefor = 0;
+    modified = true;
+}
+
+time_t icqcontact::getidlefor() const {
+    return idlefor;
+}
+
 char icqcontact::getshortstatus() const {
     if(status >= offline && status < imstatus_size) {
 	return imstatus2char[getstatus()];
