@@ -46,12 +46,12 @@ static const string seventtype[imevent::imeventtype_size] = {
 
 // -- basic imevent class -----------------------------------------------------
 
-imevent::imevent() {
+imevent::imevent() : acknowledged(false){
 }
 
 imevent::imevent(const imcontact &acont, imdirection adir, imeventtype atype, time_t asenttimestamp)
 : contact(acont), direction(adir), type(atype), timestamp(timer_current),
-  senttimestamp(asenttimestamp ? asenttimestamp : timer_current) {
+  senttimestamp(asenttimestamp ? asenttimestamp : timer_current), acknowledged(false) {
 }
 
 imevent::imevent(ifstream &f) {
@@ -202,6 +202,7 @@ immessage::immessage(const imevent &ev) {
     direction = ev.direction;
     timestamp = ev.timestamp;
     senttimestamp = ev.senttimestamp;
+    acknowledged = ev.acknowledged;
 
     const immessage *m = dynamic_cast<const immessage *>(&ev);
 
@@ -292,7 +293,7 @@ imauthorization::imauthorization(const imcontact &acont, imdirection adirection,
     text = atext;
     if(text.empty() && authtype == Request)
     switch(adirection) {
-	case outgoing: text = "Please accept my authorization to add you to my contact list."; break;
+	case outgoing: text = conf->getDefaultAuthMessage(); break;
 	case incoming: text = _("Empty authorization request message"); break;
     }
 
